summaryrefslogtreecommitdiffstats
path: root/chrome/browser/tab_contents/web_contents_view.h
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-01-28 20:14:45 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-01-28 20:14:45 +0000
commitef85d47f1a76de6a2832607b7d80c45b5c662e65 (patch)
treeb8a40f567be4abbe9f611ac4b9d9a509573c70de /chrome/browser/tab_contents/web_contents_view.h
parent90b59b78afc61c68536a30afb526628c2891731b (diff)
downloadchromium_src-ef85d47f1a76de6a2832607b7d80c45b5c662e65.zip
chromium_src-ef85d47f1a76de6a2832607b7d80c45b5c662e65.tar.gz
chromium_src-ef85d47f1a76de6a2832607b7d80c45b5c662e65.tar.bz2
Make WebContentsView portable by using the native view types.
Review URL: http://codereview.chromium.org/19632 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@8819 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/tab_contents/web_contents_view.h')
-rw-r--r--chrome/browser/tab_contents/web_contents_view.h22
1 files changed, 10 insertions, 12 deletions
diff --git a/chrome/browser/tab_contents/web_contents_view.h b/chrome/browser/tab_contents/web_contents_view.h
index 12f4ab8..ab7ae97 100644
--- a/chrome/browser/tab_contents/web_contents_view.h
+++ b/chrome/browser/tab_contents/web_contents_view.h
@@ -5,12 +5,11 @@
#ifndef CHROME_BROWSER_TAB_CONTENTS_WEB_CONTENTS_VIEW_H_
#define CHROME_BROWSER_TAB_CONTENTS_WEB_CONTENTS_VIEW_H_
-#include <windows.h>
-
#include <map>
#include <string>
#include "base/basictypes.h"
+#include "base/gfx/native_widget_types.h"
#include "base/gfx/rect.h"
#include "base/gfx/size.h"
#include "chrome/browser/renderer_host/render_view_host_delegate.h"
@@ -50,15 +49,13 @@ class WebContentsView : public RenderViewHostDelegate::View {
virtual RenderWidgetHostViewWin* CreateViewForWidget(
RenderWidgetHost* render_widget_host) = 0;
- // Returns the HWND that contains the contents of the tab.
- // TODO(brettw) this should not be necessary in this cross-platform interface.
- virtual HWND GetContainerHWND() const = 0;
+ // Returns the native widget that contains the contents of the tab.
+ virtual gfx::NativeView GetNativeView() const = 0;
- // Returns the HWND with the main content of the tab (i.e. the main render
- // view host, though there may be many popups in the tab as children of the
- // container HWND).
- // TODO(brettw) this should not be necessary in this cross-platform interface.
- virtual HWND GetContentHWND() const = 0;
+ // Returns the native widget with the main content of the tab (i.e. the main
+ // render view host, though there may be many popups in the tab as children of
+ // the container).
+ virtual gfx::NativeView GetContentNativeView() const = 0;
// Computes the rectangle for the native widget that contains the contents of
// the tab relative to its parent.
@@ -156,8 +153,9 @@ class WebContentsView : public RenderViewHostDelegate::View {
// created objects so that they can be associated with the given routes. When
// they are shown later, we'll look them up again and pass the objects to
// the Show functions rather than the route ID.
- virtual WebContents* CreateNewWindowInternal
- (int route_id, base::WaitableEvent* modal_dialog_event) = 0;
+ virtual WebContents* CreateNewWindowInternal(
+ int route_id,
+ base::WaitableEvent* modal_dialog_event) = 0;
virtual RenderWidgetHostView* CreateNewWidgetInternal(int route_id,
bool activatable) = 0;
virtual void ShowCreatedWindowInternal(WebContents* new_web_contents,